import request from '@/utils/request';

//获取仓库列表
export function wareHoustList(data){
    return request({
      url: '/local/warehouse/list',
      method: 'post',
      data: data
    })
}
//新增仓库
export function addWareHoust(data){
    return request({
      url: '/local/warehouse/create',
      method: 'post',
      data: data
    })
}
//仓库详情
export function wareHoustInfo(data){
    return request({
      url: '/local/warehouse/info',
      method: 'post',
      data: data
    })
}
//仓库编辑
export function updateWareHoust(data){
    return request({
      url: '/local/warehouse/update',
      method: 'post',
      data: data
    })
}
//仓库删除
export function deleteWareHoust(data){
    return request({
      url: '/local/warehouse/delete',
      method: 'post',
      data: data
    })
}


